@@ -8,7 +8,9 @@ from enum import Enum
 import json
 import time
 
-from bilibili_api.utils.sync import sync
+from.exceptions import ResponseCodeException
+
+from .utils.sync import sync
 
 from .utils.network_httpx import request
 from .utils.utils import get_api, join
@@ -781,7 +783,7 @@ async def get_self_history(
     return await request("GET", url=api["url"], params=params, credential=credential)
 
 
-async def get_self_coins(credential: Credential=None):
+async def get_self_coins(credential: Credential = None):
     """
     获取自己的硬币数量。
     如果接口返回错误代码则为身份校验失败
@@ -793,5 +795,75 @@ async def get_self_coins(credential: Credential=None):
         credential = Credential()
     credential.raise_for_no_sessdata()
     credential.raise_for_no_dedeuserid()
-    api = API["info"]['get_coins']
-    return (await request("GET", url=api['url'], credential=credential))['money']
+    api = API["info"]["get_coins"]
+    return (await request("GET", url=api["url"], credential=credential))["money"]
+
+
+async def get_toview_list(credential: Credential = Credential()):
+    """
+    获取稍后再看列表
+
+    Args:
+        credential(Credential): 凭据类
+
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    api = get_api("toview")["info"]["list"]
+    credential.raise_for_no_sessdata()
+    return await request("GET", api["url"], credential=credential)
+
+
+async def clear_toview_list(credential: Credential = Credential()):
+    """
+    清空稍后再看列表
+
+    Args:
+        credential(Credential): 凭据类
+
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    api = get_api("toview")["operate"]["clear"]
+    credential.raise_for_no_sessdata()
+    credential.raise_for_no_bili_jct()
+    return await request("POST", api["url"], credential=credential)
+
+
+async def delete_viewed_videos_from_toview(credential: None):
+    """
+    删除稍后再看列表已经看过的视频
+
+    Args:
+        credential(Credential): 凭据类
+
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    api = get_api("toview")["operate"]["del"]
+    credential.raise_for_no_sessdata()
+    credential.raise_for_no_bili_jct()
+    datas = {"viewed": "true"}
+    return await request("POST", api["url"], credential=credential, data=datas)
+
+
+async def check_nickname(nick_name: str=None):
+    """
+    检验昵称是否可用
+    
+    Args:
+        nick_name(str): 昵称
+
+    Returns:
+        List[bool, str]: 昵称是否可用 + 不可用原因
+    """
+    api = get_api("common")['nickname']['check_nickname']
+    params = {
+        "nickName": nick_name
+    }
+    try:
+        resp = await request("GET", api['url'], params=params)
+    except ResponseCodeException as e:
+        return False, str(e)
+    else:
+        return True, ""
